#!/bin/sh

SVNREV='$Revision: 938721 $'
SVNURL='$URL: http://subversion.mmu.acquiremedia.com/svn/amc/msrc/bin/nwsts/tags/nwsts-RelS9.2-3/src/nwsts.sh $'
SVNDATE='$Date: 2015-10-29 15:22:26 -0400 (Thu, 29 Oct 2015) $'

. /nwsys/release/bin/ga_options.sh
. /nwsys/release/bin/gautil.sh


PORT_STS="$GA_TMP/port.sts"
FILE_TMP="$GA_TMP/tmp1.file$$"
FILE_TMP2="$GA_TMP/tmp2.file$$"
FILE_TMP3="$GA_TMP/tmp3.file$$"


###########################################################################
# Retrieve list of process id's for all process with name matching
# arg1. List is stored in global variable pidlist.
###########################################################################
load_pidlist () {
    if [ "$GA_OPR_SYS" = "Solaris" -o "$GA_OPR_SYS" = "Linux" ]
    then
        pidlist="`grep -w $1 $FILE_TMP | awk '{print $1}'`"
    elif [ "$GA_OPR_SYS" = "HPUX" ]
    then
        # Since HP doesn't support the -w switch, we must explicitly
        # filter out 'f$1' so dvnews doesn't match fdvnews.
        pidlist="`egrep $1 $FILE_TMP | egrep -v f$1 | awk '{print $1}'`"
    else
        # SunOs default case
        pidlist="`egrep $1 $FILE_TMP | egrep -v '(egrep|f$1)' | awk '{print $2}'`"
    fi
}

###########################################################################
# See if process arg1 is running.
# Return 0 if not running else return the number of running processes
###########################################################################
chk_process() {
    num=0
    cnt=0
    totcnt=0
    load_pidlist $1
    if [ "X$verbose" = "XTRUE" ]
    then
        rev=`$GA_ETC/$1 --version | grep 'Build SVN Tag:' | awk -F\- '{print $2"-"$3}'`
        if [ "X$rev" = "X-" ]
        then
            rev="NA"
        fi
        pkg="$1:$rev"
    else
        pkg="$1"
    fi

    no_proc=`$GA_ECHO $pidlist | wc -w | sed -e "s/^[ 	]*//"` 

    if [ "X$pidlist" != "X" -o $no_proc -ne  0 ]
    then

        printf "    $pkg\t running\t"

        for pid in $pidlist
        do
            if [ $cnt -eq 6 ]
            then
                if [ "X$verbose" = "XTRUE" ]
                then
                    printf "\n\t\t\t\t\t"
                else
                    printf "\n\t\t\t\t"
                fi
                cnt=0
            fi
            printf "$pid "
            num=`expr $num + 1`
            cnt=`expr $cnt + 1`
            totcnt=`expr $totcnt + 1`
        done

        $GA_ECHO ""

        # Quick check for correct num of xsdisk's
        if [ "X$1" = "Xxsdisk" ]
        then
            if [ $totcnt != $GA_S_DISK_NUM ]
            then
                $GA_ECHO "\n    WARNING: improper number of s_disks running\n"
                proc_num=0
                return 0
            fi
        fi
        # Quick check for correct num of xrdisk's
        if [ "X$1" = "Xxrdisk" ]
        then
            if [ $totcnt != $GA_R_DISK_NUM ]
            then
                $GA_ECHO "\n    WARNING: improper number of r_disks running\n"
                proc_num=0
                return 0
            fi
        elif [ "X$1" = "Xxpamd" ]
        then
            # Quick check for correct num of pamd's
            if [ $totcnt != $GA_PAMD_NUM ]
            then
                $GA_ECHO "\n    WARNING: improper number of pamd running\n"
                proc_num=0
                return 0
            fi
        elif [ "X$1" = "Xquotd" ]
        then
            # Quick check for correct num of quotd's
            if [ $totcnt != $GA_QUOTD_NUM ]
            then
                $GA_ECHO "\n    WARNING: improper number of quotd running\n"
                proc_num=0
                return 0
            fi
        elif [ "X$1" = "Xdqtick" ]
        then
            # Quick check for correct num of dqtick's
            if [ $totcnt != $GA_DQTICK_NUM ]
            then
                $GA_ECHO "\n    WARNING: improper number of dqtick running\n"
                proc_num=0
                return 0
            fi
        elif [ "X$1" = "Xprofd" ]
        then
            # Quick check for correct num of profd's
            if [ $totcnt != $GA_PROFD_NUM ]
            then
                $GA_ECHO "\n    WARNING: improper number of profd running"
                proc_num=0
                return 0
            fi
        fi

        return $num
    else
        printf "    $pkg\t DOWN!\n"
        proc_num=0
        if [ "X$verbose" = "XTRUE" -o "X$long" = "XTRUE" ]
        then	
            crit_mssg $1
        fi
        return 0
    fi
}

###########################################################################
# Search log files for CRITICAL mssgs.
#
###########################################################################
crit_mssg() {

    c_flag=0
    nlogs=`ls -1 $GA_LOGS | grep '^nlog' `
    for nlog in $nlogs
    do
        critical=`grep CRITICAL: $GA_LOGS/$nlog | grep $1 ` 
        if [ "X$critical" != "X" ]
        then
            $GA_ECHO "$critical\n"
            return 
        fi
    done
}

###########################################################################
# If this is an interceiver show connection info.
###########################################################################
chk_intcvr () {
    iconf="$GA_CONF/$1.conf"

    if [ ! -f $iconf ]
    then
        return 1
    fi
    snum=`grep '^SerialNum:' $iconf | awk '{print $2}'`
    if [ "X$snum" = "X" ]
    then
        return 1
    fi
    uname=`grep '^UserName:' $iconf | awk '{print $2}'`
    tmp=`grep ^$1: $GA_CONF/port.conf | awk '{print $3}'`
    svr=`echo $tmp | awk -F: '{print $2}'`

    printf "\t\t\t\tAcct: $snum  User: $uname\n"
    printf "\t\t\t\tServer: $svr\n"
}

###########################################################################
# Check GA_FEED_HANDLER separate to show connection info for interceivers
###########################################################################
chk_feed () {

    for Feed in $GA_FEED_HANDLER
    do
        chk_process $Feed
        if [ $? -eq 0 ]
        then
            GA_WARN=TRUE
        fi
        chk_intcvr $Feed
    done

    if [ "X$GA_WARN" = "XTRUE" ]
    then
        return 0
    else
        return 1
    fi
}


############################################################################
#Main subroutine that calls everything else
############################################################################
chk_all () {

    proc_num=0
    eval $GA_PSE_CMD > $FILE_TMP 
    if [ "X$GA_UPTIME" != "XNA" ]
    then
        printf "\nRelease: $GA_RELEASE, up since: $GA_UPTIME"
    fi

    # If garpd is configured, then we must check for primary/secondary
    # server status.  We display neither if state has not been defined.

    GA_list_contains garpd "$GA_ALL $GA_FEED_PROC"
    if [ $? -eq 1 ]
    then
        # Add (Primary) to this line if touch file exists.
        if [ -f $GA_CONF_SYS/IsPrimary ]
        then
            $GA_ECHO "  (Primary)\n"
            cat $GA_CONF_SYS/IsPrimary | grep -v INTERVAL
            $GA_ECHO ""
        elif [ -f $GA_CONF_SYS/IsSecondary ]
        then
            $GA_ECHO "  (Secondary)\n"
            cat $GA_CONF_SYS/IsSecondary | grep -v INTERVAL
            $GA_ECHO ""
        elif [ -f $GA_CONF_SYS/IsMulti ]
        then
            $GA_ECHO "  (Multi)\n"
            cat $GA_CONF_SYS/IsMulti | grep -v INTERVAL
            $GA_ECHO ""
        else
            $GA_ECHO "  (Neither)\n"
            $GA_ECHO ""
        fi
    else
        $GA_ECHO ""
        $GA_ECHO ""
    fi

    for Proc in $GA_ALL
    do
        chk_process $Proc
        if [ $? -eq 0 ]
        then
            GA_WARN=TRUE
        fi
    done

    if [ "X" != "X$GA_FEED_HANDLER_QUOT" ]
    then
        $GA_ECHO ""
        proc_num=0
        for Feed in $GA_FEED_HANDLER_QUOT
        do
            chk_process $Feed
            if [ $? -eq 0 ]
            then
                GA_WARN=TRUE
            fi
        done
    fi

    if [ "X" != "X$GA_FEED_PROC" ]
    then
        $GA_ECHO ""
        proc_num=0
        for Feed in $GA_FEED_PROC
        do
            chk_process $Feed
            if [ $? -eq 0 ]
            then
                GA_WARN=TRUE
            fi
        done
    fi

    if [ "X" != "X$GA_FEED_HANDLER" ]
    then
        $GA_ECHO ""
        chk_feed
        if [ $? -eq 0 ]
        then
            GA_WARN=TRUE
        fi
    fi

    if [  -f $GA_INDEXING_FILE ]
    then
        $GA_ECHO "\n    STATUS: System is currently indexing!"
    fi

    if [ "$GA_WARN" = "TRUE" ]
    then
        $GA_ECHO "    WARNING: All processes are NOT running! "
    else
        printf "\n    **** All processes are up and running ****\n"
        ExitStatus=0
    fi
    printf "\n"
}

###################################################################
# Help
###################################################################
ihelp() {

    printf "\n     Acquire Media Software System Status Utility\n\n"
    printf "     Usage: $iam$newname -h -l -s -v -t [time]\n"
    printf "\t -h Online help\n"
    printf "\t -l Performs search for last CRITICAL messages in nlogs\n"
    printf "\t -v Verbose - includes package revision information\n"
    printf "\t -t [time] Time step for periodic checks (Kill w/ ^C).\n"
    exit 1
}

###################################################################
# Gracefull Exit
###################################################################
gracefull_exit() {

    rm -f  $FILE_TMP $FILE_TMP2 $FILE_TMP3
    exit
}

##############
# MAIN PROGRAM
##############
myname=`basename $0`
save_options=$*
verbose=FALSE
long=FALSE
wrap=FALSE
time_chck=FALSE

# Force environment rebuild every time.
GA_init REBUILD

trap 'gracefull_exit' 1 2 9 15

if [ "$GA_OPR_SYS_VER" = "09" ]
then
    set -- `getopt hvlsdt:w: $save_options `
    for OPT in $*
    do
        case $OPT in
            -h) Help="TRUE"
            shift
            ;;
            -v)   verbose=TRUE 
            shift
            ;;
            -l)   long=TRUE 
            shift
            ;;
            -t)   time_chck=TRUE 
            shift
            time=$OPTARG 
            ;;
            -w)   wrap=true 
            shift
            iam=$OPTARG 
            ;;
            --)   shift
            break
            ;;
        esac
    done
else

    while getopts hvlsdt:w: OPT
    do
        case $OPT in
            h)   Help="TRUE"
            ;;
            v)   verbose=TRUE
            ;;
            l)   long=TRUE
            ;;
            t)   time_chck=TRUE
            time=$OPTARG
            ;;
            w)   wrap=TRUE 
            iam=$OPTARG
            ;;
            *)   Help="TRUE" 
            ;;
        esac
    done
fi

# cut nw from program basename
newname=`$GA_ECHO $myname | sed -e 's/nw/ /'` 

if [ "X$Help" = "XTRUE" ]
then
    ihelp
fi  
if [  "X$wrap" = "XFALSE" ]
then
    newname=$myname
fi

if [ "X$time_chck" = "XTRUE" ]
then
    while [ 1 ]
    do
        chk_all
        sleep $time
        $GA_ECHO ""
    done

else
    chk_all
fi
gracefull_exit
###########################################################################
