#ifndef WNDPCOMM_H
#define WNDPCOMM_H

#ifdef	__cplusplus
extern "C" {
#endif

#include <stdint.h>

#include "wndp.h"

typedef enum {WNDP_FLTR_INCLUDE, WNDP_FLTR_EXCLUDE} WNDP_FLTR_MODE;

typedef struct {
	char provider[8 + 1];
	char service[8 + 1];
} WNDP_FLTR_ITEM;

typedef struct {
	char date[8 + 1];
	char time[6 + 1];
} WNDP_WHEN;

typedef struct {
	char name[WNDP_FILENAME_LEN];
	/*long size;*/
    uint32_t size;
	char *data;
} WNDP_FILE_INFO;

typedef struct {
	WNDP_WHEN when;
	char data_class[50 + 1];
	int nfiles;
	WNDP_FILE_INFO files[WNDP_MAX_FILES];
	int channel;
} WNDP_MESSAGE;

#define WNDP_CHANNEL_MAX 10

int wndp_set_channel (int channel_number);
int wndp_get_channel (void);
void wndp_set_retry_strategy (int retry_forever);
int wndp_connect (char *server, int portnum, int version);
int wndp_login (char *username, char *password);
int wndp_set_classes (char *classes);
int wndp_set_fltr (WNDP_FLTR_MODE mode, WNDP_FLTR_ITEM *items);
int wndp_start_from (WNDP_WHEN *from);
int wndp_get_next_message (WNDP_MESSAGE *msg, long seconds);
int wndp_get_file (WNDP_FILE_INFO *file_info);
int wndp_get_file_chunk (char *filename, char *buf, long bufsize,
							long *chunk_size);
void wndp_free_buffer (char **buf);
void wndp_disconnect (void);
char *wndp_get_err_str (void);

int wndp_load_from (WNDP_WHEN *when, char *from_file);
int wndp_load_from2 (WNDP_WHEN *when, char *from_file, char *touch_file);
int wndp_save_from (WNDP_WHEN *when);

typedef struct wndp_context WNDP_CONTEXT;
WNDP_CONTEXT *wndp_get_context (void);
int wndp_set_rqst_options_r (WNDP_CONTEXT *wndp_ctx, char *options);
int wndp_set_rqst_options (char *options);
void wndp_free_context (WNDP_CONTEXT *wndp_ctx);
int wndp_set_channel_r (WNDP_CONTEXT* ctx, int channel_number);
int wndp_connect_r (WNDP_CONTEXT* ctx, char *in_server, int portnum, int version);
int wndp_login_r (WNDP_CONTEXT* ctx, char *username, char *password);
int wndp_set_classes_r (WNDP_CONTEXT* ctx, char *classes);
int wndp_set_fltr_r (WNDP_CONTEXT* ctx, WNDP_FLTR_MODE mode, WNDP_FLTR_ITEM *items);
int wndp_start_from_r (WNDP_CONTEXT* ctx, WNDP_WHEN *from);
int wndp_get_next_message_r (WNDP_CONTEXT* ctx, WNDP_MESSAGE *msg, long seconds);
int wndp_get_next_data_stream_message_r (WNDP_CONTEXT* ctx, WNDP_MESSAGE *msg, long seconds);
int wndp_get_file_r (WNDP_CONTEXT* ctx, WNDP_FILE_INFO *file_info);
int wndp_get_file_chunk_r (WNDP_CONTEXT* ctx, char *filename, char *buf, long bufsize,
        long *chunk_size);
void wndp_disconnect_r (WNDP_CONTEXT* ctx);
char *wndp_get_err_str_r (WNDP_CONTEXT* ctx);
int wndp_load_from_r (WNDP_CONTEXT* ctx, WNDP_WHEN *when, char *from_file);
int wndp_load_from2_r (WNDP_CONTEXT* ctx, WNDP_WHEN *when, char *from_file,
                        char *touch_file);
int wndp_save_from_r (WNDP_CONTEXT* ctx, WNDP_WHEN *when);


#ifdef	__cplusplus
}
#endif

#endif	/* WNDPCOMM_H */
