#ifndef RTRSNEWSML_H
#define RTRSNEWSML_H

#ifdef  __cplusplus
extern "C" {
#endif

#include "xmlparse/xmlparse.h"

#ifdef NOWAVO
#include "expat.h"
#else
#include "expat/expat.h"
#endif


#define RTRS_LINK_LIST_MAX 20

typedef struct {
    char *headline;
    char *slug;
    char *id;
    char *class; 
} RTRS_LINK_LIST;

typedef struct {
    char *encoding;
    char *itemid;
    char *id;
    char *date;
    char *publisher;
    char *xml_lang;
    int parts;
    int revision;
    char *title;            /* A short headline for display purposes. */
    char *headline;
    char *byline;
    char *copyright;
    char *dateline;
    char *caption;
    char *genre;
    char *content;
    char *firstcreatedate;  // rtrenhcd want the first created date

    XN_ELEMENT iim_category;
    XN_ELEMENT iim_supp_category;
    XN_ELEMENT n2000_topic;
    XN_ELEMENT iim_subject_reference;
    XN_ELEMENT routing;
    XN_ELEMENT ofinterestto;

    char *product;
    char *priority;
    char *service;
    char *slug;
    char *thumbnail;
    char *preview;
    char *base_image;

    char *pubstatqcode;  /* if canceled or withheld sends a kill */

    XN_ELEMENT misctags;    /* Miscellaneous tags, not otherwise returned. */

    RTRS_LINK_LIST rll[RTRS_LINK_LIST_MAX];

    /* g2 version data */
    XN_ELEMENT signals;

    char *description;  /* for caption on photos */

} RTRSNEWSML;


typedef struct {
    int tag;
    char tag_name[50];
    char *tmpstr;
    int tlen;
    int curr_len;
} RTRSNEWSML_LEVEL_INFO;

typedef struct {
    int iim_category;
    int iim_supp_category;
    int n2000_topic;
    int iim_subject_reference;
    int routing;
    int ofinterestto;
    int misctags;
    int signals;
} RUD_ALLOCS;

typedef struct {
    RTRSNEWSML rtrsnewsml;
    char filename[512];
    RTRSNEWSML_LEVEL_INFO x[MAX_XMLPARSE_LEVELS];
    int level;
    RUD_ALLOCS n;
    /* move the g2 parsing globals here to make the code rentrant and thread
       safe...  glw 20150306
    */
    int BufLen;  //  = 0;
    int in_body;  // = FALSE; 
    int llj;  // = -1;
    int isLinkedList;  // = 0;
    int isPackageSet;  // = 0;
    int do_description;  // = 0;
    int in_itemeta;  // =0;

    /* data that was staticly allocated in the g2newsml_parse routine.
     */
    char save_filename[1000];  // = "";
    XML_Parser parser;  // = NULL;

} RTRSNEWSML_USER_DATA;

/* library functions for parsing the reuters newsml data
 */

    int rtrsnewsml_parse_r (RTRSNEWSML_USER_DATA *sud, XML_Parser *parser,
                            char *filename, char *save_filename, char *buf,
                            long buflen, int is_final_data);

    RTRSNEWSML *rtrsnewsml_parse (char *filename, char *buf, long buflen,
                                  int is_final_data);
    RTRSNEWSML *iptcnewsml_parse (char *filename, char *buf, long buflen,
                                  int is_final_data);
    int parse_newsitemid (char *newsitemid, char **itemid, char **gmt);

    /** @fn g2newsml_parse
        @brief parses the g2newsml data.  allocates and returns a story 
        structure  WARNING is not reentrant or thread safe...
    */
    RTRSNEWSML *g2newsml_parse (char *filename, char *buf, long buflen,
                                int is_final_data);
    /** @fn g2newsml_parse_r 
        @brief  reentrant and thread safe version of the parser. global items
        from the g2 parsing code were moved into the rud structure. 
    */
    int g2newsml_parse_r (RTRSNEWSML_USER_DATA *rud, XML_Parser *parser,
                          char *filename, char *save_filename,
                          char *buf, long buflen,
                          int is_final_data);
    /** @fn
        @brief cleans up the various story items.  is an alias that wraps
        the local static outine in the g2 parsing module.
    */
    extern void reset_rtrsnewsmlg2_user_data (RTRSNEWSML_USER_DATA *rud);

#ifdef  __cplusplus
}
#endif

#endif /** RTRSNEWSML_H **/


/* end of file */
